@@ -20,6 +20,9 @@ def index():
 
     return open(JS_FILE).read()
  
-if __name__ == "__main__":
+def main():
     app.debug = config.DEBUG 
     app.run(host=config.HOST, port=config.PORT)
+
+if __name__ == "__main__":
+    main()
